QMetaTypeType

Struct QMetaTypeType 

#[repr(transparent)]
pub struct QMetaTypeType { pub repr: i32, }
Types supported by QMetaType. This enum list is non-exhaustive, as additional types may be registered during runtime.

User-registered types should be greater than or equal to QMetaTypeType::User.

Fields

repr: i32

Implementations



impl QMetaTypeType

pub const UnknownType: QMetaTypeType

This is an invalid type id. It is returned for types that are not registered.

pub const Bool: QMetaTypeType

pub const Int: QMetaTypeType

pub const UInt: QMetaTypeType

pub const LongLong: QMetaTypeType

pub const ULongLong: QMetaTypeType

pub const Double: QMetaTypeType

pub const Long: QMetaTypeType

pub const Short: QMetaTypeType

pub const Char: QMetaTypeType

pub const ULong: QMetaTypeType

pub const UShort: QMetaTypeType

pub const UChar: QMetaTypeType

pub const Float: QMetaTypeType

pub const VoidStar: QMetaTypeType

pub const QChar: QMetaTypeType

pub const QString: QMetaTypeType

pub const QStringList: QMetaTypeType

pub const QByteArray: QMetaTypeType

pub const QBitArray: QMetaTypeType

pub const QDate: QMetaTypeType

pub const QTime: QMetaTypeType

pub const QDateTime: QMetaTypeType

pub const QUrl: QMetaTypeType

pub const QLocale: QMetaTypeType

pub const QRect: QMetaTypeType

pub const QRectF: QMetaTypeType

pub const QSize: QMetaTypeType

pub const QSizeF: QMetaTypeType

pub const QLine: QMetaTypeType

pub const QLineF: QMetaTypeType

pub const QPoint: QMetaTypeType

pub const QPointF: QMetaTypeType

pub const QEasingCurve: QMetaTypeType

pub const QUuid: QMetaTypeType

pub const QVariant: QMetaTypeType

pub const QModelIndex: QMetaTypeType

pub const QPersistentModelIndex: QMetaTypeType

pub const QRegularExpression: QMetaTypeType

pub const QJsonValue: QMetaTypeType

pub const QJsonObject: QMetaTypeType

pub const QJsonArray: QMetaTypeType

pub const QJsonDocument: QMetaTypeType

pub const QByteArrayList: QMetaTypeType

pub const QObjectStar: QMetaTypeType

pub const SChar: QMetaTypeType

pub const Void: QMetaTypeType

pub const Nullptr: QMetaTypeType

pub const QVariantMap: QMetaTypeType

pub const QVariantList: QMetaTypeType

pub const QVariantHash: QMetaTypeType

pub const QCborSimpleType: QMetaTypeType

pub const QCborValue: QMetaTypeType

pub const QCborArray: QMetaTypeType

pub const QCborMap: QMetaTypeType

pub const Char16: QMetaTypeType

pub const Char32: QMetaTypeType

pub const QFont: QMetaTypeType

pub const QPixmap: QMetaTypeType

pub const QBrush: QMetaTypeType

pub const QColor: QMetaTypeType

pub const QPalette: QMetaTypeType

pub const QIcon: QMetaTypeType

pub const QImage: QMetaTypeType

pub const QPolygon: QMetaTypeType

pub const QRegion: QMetaTypeType

pub const QBitmap: QMetaTypeType

pub const QCursor: QMetaTypeType

pub const QKeySequence: QMetaTypeType

pub const QPen: QMetaTypeType

pub const QTextLength: QMetaTypeType

pub const QTextFormat: QMetaTypeType

pub const QTransform: QMetaTypeType

pub const QMatrix4x4: QMetaTypeType

pub const QVector2D: QMetaTypeType

pub const QVector3D: QMetaTypeType

pub const QVector4D: QMetaTypeType

pub const QQuaternion: QMetaTypeType

pub const QPolygonF: QMetaTypeType

pub const QColorSpace: QMetaTypeType

pub const QSizePolicy: QMetaTypeType

pub const User: QMetaTypeType